##### CarSetup.py
#
#  Create vehicle constraint Class KX_VehicleWrapper Blender 2.49b
#
####################################################

#import PhysicsConstraints
import PhysicsConstraints

# Get owner
controller = GameLogic.getCurrentController()
owner = controller.owner
    
# get physics ID
car_PhysicsID = owner.getPhysicsId()
 
# create a vehicle constraint
vehicle_Constraint = PhysicsConstraints.createConstraint(car_PhysicsID, 0, 11)
 
# get the constraint ID
constraint_ID = vehicle_Constraint.getConstraintId()

# save constraint_ID as a car variable
owner["constraint_ID"] = constraint_ID

# get the vehicle constraint ID
vehicle = PhysicsConstraints.getVehicleConstraint(constraint_ID)

# get current scene
scene = GameLogic.getCurrentScene()

# get list of objects in scene
objList = scene.objects

# use the names to get the tire objects
tire_FD = objList["OBTire_1.001"]
tire_FP = objList["OBTire_2.001"]
tire_RD = objList["OBTire_3.001"]
tire_RP = objList["OBTire_4.001"]

# Front driver tire position from car object center
tirePos_FD = [ -1.0, 1.4, -0.5]

# Front passenger tire position from car object center
tirePos_FP = [ 1.0, 1.4, -0.5]

# Rear driver tire position from car object center
tirePos_RD = [ -1.0, -0.9, -0.4]

# Rear passenger tire position from car object center
tirePos_RP = [ 1.0, -0.9, -0.4]

# suspension angle from car object center
suspension_Angle = [ 0.0, 0.0, -1.0]

# tire axis attached to car axle
tireAxis = [ -1.0, 0.0, 0.0]

# set suspension height
suspensionHeight_FD = 0.2
suspensionHeight_FP = 0.2
suspensionHeight_RD = 0.35
suspensionHeight_RP = 0.35

# set tire radius
tireRadius_FD = 0.38
tireRadius_FP = 0.38
tireRadius_RD = 0.4
tireRadius_RP = 0.4

# tire has steering?
tireSteer_FD = True
tireSteer_FP = True
tireSteer_RD = False
tireSteer_RP = False 

# Add front driver tire (tire 0)
vehicle.addWheel( tire_FD, tirePos_FD, suspension_Angle, tireAxis, suspensionHeight_FD,  tireRadius_FD, tireSteer_FD )

# Add front passenger tire (tire 1)
vehicle.addWheel( tire_FP, tirePos_FP, suspension_Angle, tireAxis, suspensionHeight_FP,  tireRadius_FP, tireSteer_FP )

# Add rear driver tire (tire 2)
vehicle.addWheel( tire_RD, tirePos_RD, suspension_Angle, tireAxis, suspensionHeight_RD,  tireRadius_RD, tireSteer_RD )

# Add rear passenger tire (tire 3)
vehicle.addWheel( tire_RP, tirePos_RP, suspension_Angle, tireAxis, suspensionHeight_RP,  tireRadius_RP, tireSteer_RP )

##########################################################
# Settings with car = 200 kg
##########################################################
# Set Suspension Compression
SuspComp = 10.0
vehicle.setSuspensionCompression(SuspComp, 0)
vehicle.setSuspensionCompression(SuspComp, 1)
vehicle.setSuspensionCompression(SuspComp, 2)
vehicle.setSuspensionCompression(SuspComp, 3)

##########################################################
	
# Set Suspension Damping
SuspDamp = 100.0
vehicle.setSuspensionDamping(SuspDamp, 0)
vehicle.setSuspensionDamping(SuspDamp, 1)
vehicle.setSuspensionDamping(SuspDamp, 2)
vehicle.setSuspensionDamping(SuspDamp, 3)

###########################################################

# Set Suspension Stiffness
SuspStiff = 100.0
vehicle.setSuspensionStiffness(SuspStiff, 0)
vehicle.setSuspensionStiffness(SuspStiff, 1)
vehicle.setSuspensionStiffness(SuspStiff, 2)
vehicle.setSuspensionStiffness(SuspStiff, 3)

############################################################

# Set Roll Influence
Roll = 0.05
vehicle.setRollInfluence(Roll, 0)
vehicle.setRollInfluence(Roll, 1)
vehicle.setRollInfluence(Roll, 2)
vehicle.setRollInfluence(Roll, 3)

##########################################################

# Set Tyre Friction
TyreFrict = 5.0
vehicle.setTyreFriction(TyreFrict, 0)
vehicle.setTyreFriction(TyreFrict, 1)
vehicle.setTyreFriction(TyreFrict, 2)
vehicle.setTyreFriction(TyreFrict, 3)
